# Package Overview
<p align="justify">
<i>Wordhoard</i> is an application that can be used to build comprehensive antonyms and synonyms lists for words.  It can also be used to obtain 
definitions for words.  

More details documentation is located at this <a href="https://github.com/johnbumgarner/wordhoard/blob/master/README.md">link</a> on GitHub.
<p>

# Licence 
<p align="justify">
Distributed under the <a href="https://github.com/johnbumgarner/wordhoard/blob/master/LICENSE">MIT Licence</a>
<p>

# Current Version
<p align="justify">
version 1.1 
release type: initial 
release date: 10-21-2020
<p>

# Developed by:
<p align="justify">
John Bumgarner 2020
<p>